@@ -43,6 +43,9 @@ gboolean            path_is_dir                  (const gchar *s);
 
 gboolean            dir_is_empty                 (const gchar *s);
 
+gboolean            path_in_path                 (const char  *path_src,
+						  const char  *path_dest);
+
 GnomeVFSFileSize    get_file_size                (const gchar *s);
 
 time_t              get_file_mtime               (const gchar *s);
@@ -80,6 +83,9 @@ GList *             path_list_dup                (GList *path_list);
 gboolean            is_mime_type                 (const char* type, 
 						  const char* pattern);
 
+char*               escape_str                   (const char  *str, 
+						  const char  *meta_chars);
+
 gchar *             shell_escape                 (const gchar *filename);
 
 gchar *             application_get_command      (const GnomeVFSMimeApplication *app);
@@ -105,8 +111,7 @@ char **             split_line                   (const char *line,
 const char *        get_last_field               (const char *line,
 						  int         last_field);
 
-
-char *              get_temp_work_dir_name       ();
+char *              get_temp_work_dir_name       (void);
 
 
 #endif /* FILE_UTILS_H */
